@@ -2,12 +2,14 @@
 //!
 //! Handcrafted, idiomatic rust artifacts based on based on the [Alonzo CDDL](https://github.com/input-output-hk/cardano-ledger/blob/master/eras/alonzo/test-suite/cddl-files/alonzo.cddl) file in IOHK repo.
 
-use minicbor::{bytes::ByteVec, data::Tag};
-use minicbor_derive::{Decode, Encode};
+use pallas_codec::minicbor::{bytes::ByteVec, data::Int, data::Tag, Decode, Encode};
 use pallas_crypto::hash::Hash;
 use std::ops::Deref;
 
-use crate::utils::{KeyValuePairs, MaybeIndefArray};
+use pallas_codec::utils::{KeyValuePairs, MaybeIndefArray};
+
+// required for derive attrs to work
+use pallas_codec::minicbor;
 
 #[derive(Encode, Decode, Debug, PartialEq, Clone)]
 pub struct VrfCert(#[n(0)] pub ByteVec, #[n(1)] pub ByteVec);
@@ -915,7 +917,7 @@ big_nint = #6.3(bounded_bytes) ; New
 
 #[derive(Debug, PartialEq, Eq, PartialOrd, Ord)]
 pub enum BigInt {
-    Int(i64),
+    Int(Int),
     BigUInt(ByteVec),
     BigNInt(ByteVec),
 }
@@ -1223,7 +1225,7 @@ pub struct AlonzoAuxiliaryData {
 
 #[derive(Debug, PartialEq, Eq, PartialOrd, Ord)]
 pub enum Metadatum {
-    Int(i64),
+    Int(Int),
     Bytes(ByteVec),
     Text(String),
     Array(MaybeIndefArray<Metadatum>),
@@ -1235,35 +1237,39 @@ impl<'b> minicbor::Decode<'b> for Metadatum {
         match d.datatype()? {
             minicbor::data::Type::U8 => {
                 let i = d.u8()?;
-                Ok(Metadatum::Int(i as i64))
+                Ok(Metadatum::Int(i.into()))
             }
             minicbor::data::Type::U16 => {
                 let i = d.u16()?;
-                Ok(Metadatum::Int(i as i64))
+                Ok(Metadatum::Int(i.into()))
             }
             minicbor::data::Type::U32 => {
                 let i = d.u32()?;
-                Ok(Metadatum::Int(i as i64))
+                Ok(Metadatum::Int(i.into()))
             }
             minicbor::data::Type::U64 => {
                 let i = d.u64()?;
-                Ok(Metadatum::Int(i as i64))
+                Ok(Metadatum::Int(i.into()))
             }
             minicbor::data::Type::I8 => {
                 let i = d.i8()?;
-                Ok(Metadatum::Int(i as i64))
+                Ok(Metadatum::Int(i.into()))
             }
             minicbor::data::Type::I16 => {
                 let i = d.i16()?;
-                Ok(Metadatum::Int(i as i64))
+                Ok(Metadatum::Int(i.into()))
             }
             minicbor::data::Type::I32 => {
                 let i = d.i32()?;
-                Ok(Metadatum::Int(i as i64))
+                Ok(Metadatum::Int(i.into()))
             }
             minicbor::data::Type::I64 => {
                 let i = d.i64()?;
-                Ok(Metadatum::Int(i as i64))
+                Ok(Metadatum::Int(i.into()))
+            }
+            minicbor::data::Type::Int => {
+                let i = d.int()?;
+                Ok(Metadatum::Int(i))
             }
             minicbor::data::Type::Bytes => Ok(Metadatum::Bytes(d.decode()?)),
             minicbor::data::Type::String => Ok(Metadatum::Text(d.decode()?)),
@@ -1396,7 +1402,7 @@ pub struct BlockWrapper(#[n(0)] pub u16, #[n(1)] pub Block);
 mod tests {
     use super::BlockWrapper;
     use crate::Fragment;
-    use minicbor::{self, to_vec};
+    use pallas_codec::minicbor::to_vec;
 
     #[test]
     fn block_isomorphic_decoding_encoding() {
@@ -1430,6 +1436,12 @@ mod tests {
             include_str!("test_data/test17.block"),
             // peculiar block with strange AuxiliaryData variant
             include_str!("test_data/test18.block"),
+            // peculiar block with strange AuxiliaryData variant
+            include_str!("test_data/test18.block"),
+            // peculiar block with nevative i64 overflow
+            include_str!("test_data/test19.block"),
+            // peculiar block with very BigInt in plutus code
+            include_str!("test_data/test20.block"),
         ];
 
         for (idx, block_str) in test_blocks.iter().enumerate() {
